==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_comparer' => 'Zobraziť rozdiely',

	// D
	'diff_para_ajoute' => 'Pridaný odsek',
	'diff_para_deplace' => 'Presunutý odsek',
	'diff_para_supprime' => 'Odstránený odsek',
	'diff_texte_ajoute' => 'Pridaný text',
	'diff_texte_deplace' => 'Presunutý text',
	'diff_texte_supprime' => 'Odstránený text',
	'differences_versions' => 'Rozdiely medzi verziou N<sup>o</sup>@id_version@ a verziou N<sup>o</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Obnoviť verziu N<sup>o</sup>@version@',
	'icone_suivi_revisions' => 'Sledovanie zmien',
	'info_1_revision' => '1 zmena',
	'info_aucune_revision' => 'Žiadna zmena',
	'info_historique' => 'Opravy:',
	'info_historique_lien' => 'Zobraziť zoznam verzií',
	'info_historique_titre' => 'Sledovanie opráv',
	'info_nb_revisions' => '@nb@ zmien',

	// L
	'label_choisir_id_version' => 'Vyberte si verzie, ktoré chcete porovnať',
	'label_config_revisions_objets' => 'Na ktoré objekty aktivovať zmeny:',

	// M
	'message_valider_recuperer_version' => 'Ak sa chcete vrátiť k tejto verzii, potvrďte formulár.',

	// O
	'objet_editorial' => 'objekt',

	// P
	'plugin_update' => 'Aktualizovať zásuvný modul "Révisions" na verziu @version@.',

	// T
	'titre_form_revisions_objets' => 'Aktivovať zmeny',
	'titre_restaurer_version' => 'Obnoviť verziu',
	'titre_revisions' => 'Zmeny',

	// V
	'version_deplace_rubrique' => 'Presunuté z <b>"@from@"</b> na <b>"@to@".</b>',
	'version_initiale' => 'Prvá verzia',
	'voir_differences' => 'Zobraziť rozdiely',
	'voir_mes_revisions' => 'Viacej zmien',
	'voir_revisions' => 'Zobraziť rozdiely (@objet@ @id_objet@: @titre@)',
	'voir_toutes_les_revisions' => 'Všetky zmeny'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=sk
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_comparer' => 'Zobraziť rozdiely',

	// D
	'diff_para_ajoute' => 'Pridaný odsek',
	'diff_para_deplace' => 'Presunutý odsek',
	'diff_para_supprime' => 'Odstránený odsek',
	'diff_texte_ajoute' => 'Pridaný text',
	'diff_texte_deplace' => 'Presunutý text',
	'diff_texte_supprime' => 'Odstránený text',
	'differences_versions' => 'Rozdiely medzi verziou N<sup>o</sup>@id_version@ a verziou N<sup>o</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Obnoviť verziu N<sup>o</sup>@version@',
	'icone_suivi_revisions' => 'Sledovanie zmien',
	'info_1_revision' => '1 zmena',
	'info_aucune_revision' => 'Žiadna zmena',
	'info_historique' => 'Opravy:',
	'info_historique_lien' => 'Zobraziť zoznam verzií',
	'info_historique_titre' => 'Sledovanie opráv',
	'info_nb_revisions' => '@nb@ zmien',

	// L
	'label_choisir_id_version' => 'Vyberte si verzie, ktoré chcete porovnať',
	'label_config_revisions_objets' => 'Na ktoré objekty aktivovať zmeny:',

	// M
	'message_valider_recuperer_version' => 'Ak sa chcete vrátiť k tejto verzii, potvrďte formulár.',

	// O
	'objet_editorial' => 'objekt',

	// P
	'plugin_update' => 'Aktualizovať zásuvný modul "Révisions" na verziu @version@.',

	// T
	'titre_form_revisions_objets' => 'Aktivovať zmeny',
	'titre_restaurer_version' => 'Obnoviť verziu',
	'titre_revisions' => 'Zmeny',

	// V
	'version_deplace_rubrique' => 'Presunuté z <b>"@from@"</b> na <b>"@to@".</b>',
	'version_initiale' => 'Prvá verzia',
	'voir_differences' => 'Zobraziť rozdiely',
	'voir_mes_revisions' => 'Viacej zmien',
	'voir_revisions' => 'Zobraziť rozdiely (@objet@ @id_objet@: @titre@)',
	'voir_toutes_les_revisions' => 'Všetky zmeny',
];
